@@ -78,7 +78,7 @@ inline uint64_t ntoh64(uint64_t x) { return x; }
 inline uint64_t hton64(uint64_t x) { return x; }
 #else // !WORDS_BIGENDIAN
 inline uint64_t byteswap64(uint64_t x) {
-  uint64_t v1 = ntohl(x & 0x00000000ffffffff);
+  uint64_t v1 = ntohl(x & 0x00000000ffffffffllu);
   uint64_t v2 = ntohl(x >> 32);
   return (v1 << 32)|v2;
 }
@@ -88,11 +88,8 @@ inline uint64_t hton64(uint64_t x) { return byteswap64(x); }
 
 namespace util {
 
-void split(std::pair<std::string, std::string>& hp,
-           const std::string& src, char delim);
-
-std::pair<std::string, std::string>
-split(const std::string& src, const std::string& delims);
+void divide
+(std::pair<std::string, std::string>& hp, const std::string& src, char delim);
 
 template<typename T>
 std::string uitos(T value, bool comma = false)
@@ -126,13 +123,29 @@ std::string itos(int64_t value, bool comma = false);
 int64_t difftv(struct timeval tv1, struct timeval tv2);
 int32_t difftvsec(struct timeval tv1, struct timeval tv2);
 
-extern const std::string DEFAULT_TRIM_CHARSET;
+extern const std::string DEFAULT_STRIP_CHARSET;
 
-std::string trim(const std::string& src,
-                 const std::string& trimCharset = DEFAULT_TRIM_CHARSET);
+template<typename InputIterator>
+std::string stripIter
+(InputIterator first, InputIterator last,
+ const std::string& chars = DEFAULT_STRIP_CHARSET)
+{
+  if(std::distance(first, last) == 0) {
+    return A2STR::NIL;
+  }
+  for(; first != last &&
+        std::find(chars.begin(), chars.end(), *first) != chars.end(); ++first);
+  if(first == last) {
+    return A2STR::NIL;
+  }
+  InputIterator left = last-1;
+  for(; left != first &&
+        std::find(chars.begin(), chars.end(), *left) != chars.end(); --left);
+  return std::string(first, left+1);
+}
 
-void trimSelf(std::string& str,
-              const std::string& trimCharset = DEFAULT_TRIM_CHARSET);
+std::string strip
+(const std::string& str, const std::string& chars = DEFAULT_STRIP_CHARSET);
 
 bool startsWith(const std::string& target, const std::string& part);
 
@@ -148,6 +161,8 @@ bool inRFC3986ReservedChars(const char c);
 
 bool inRFC3986UnreservedChars(const char c);
 
+bool isUtf8(const std::string& str);
+
 std::string percentDecode(const std::string& target);
 
 std::string torrentPercentEncode(const unsigned char* target, size_t len);
@@ -179,6 +194,8 @@ bool parseUIntNoThrow(uint32_t& result, const std::string& s, int base = 10);
 
 int64_t parseLLInt(const std::string& s, int32_t base = 10);
 
+bool parseLLIntNoThrow(int64_t& result, const std::string& s, int base = 10);
+
 uint64_t parseULLInt(const std::string& s, int base = 10);
 
 IntSequence parseIntRange(const std::string& src);
@@ -213,6 +230,10 @@ std::string toUpper(const std::string& src);
 
 std::string toLower(const std::string& src);
 
+void uppercase(std::string& s);
+
+void lowercase(std::string& s);
+
 bool isNumericHost(const std::string& name);
 
 void setGlobalSignalHandler(int signal, void (*handler)(int), int flags);
@@ -314,33 +335,30 @@ std::map<size_t, std::string> createIndexPathMap(std::istream& i);
  */
 template<typename OutputIterator>
 OutputIterator split(const std::string& src, OutputIterator out,
-                     const std::string& delims, bool doTrim = false,
+                     const std::string& delims, bool doStrip = false,
                      bool allowEmpty = false)
 {
-  std::string::size_type p = 0;
-  while(1) {
-    std::string::size_type np = src.find_first_of(delims, p);
-    if(np == std::string::npos) {
-      std::string term = src.substr(p);
-      if(doTrim) {
-        term = util::trim(term);
-      }
-      if(allowEmpty || !term.empty()) {
-        *out = term;
-        ++out;
-      }
-      break;
+  std::string::const_iterator first = src.begin();
+  std::string::const_iterator last = src.end();
+  for(std::string::const_iterator i = first; i != last;) {
+    std::string::const_iterator j = i;
+    for(; j != last &&
+          std::find(delims.begin(), delims.end(), *j) == delims.end(); ++j);
+    std::string t = doStrip?util::stripIter(i, j):std::string(i, j);
+    if(allowEmpty || !t.empty()) {
+      *out++ = t;
     }
-    std::string term = src.substr(p, np-p);
-    if(doTrim) {
-      term = util::trim(term);
-    }
-    p = np+1;
-    if(allowEmpty || !term.empty()) {
-      *out = term;
-      ++out;
+    i = j;
+    if(j != last) {
+      ++i;
     }
   }
+  if(allowEmpty &&
+     (src.empty() ||
+      std::find(delims.begin(), delims.end(),
+                src[src.size()-1]) != delims.end())) {
+    *out++ = A2STR::NIL;
+  }
   return out;
 }
 
@@ -396,7 +414,7 @@ bool inSameCidrBlock(const std::string& ip1, const std::string& ip2, int bits);
 
 void removeMetalinkContentTypes(const SharedHandle<RequestGroup>& group);
 
-void executeHook(const std::string& command, gid_t gid);
+void executeHook(const std::string& command, const std::string& arg);
 
 void executeHookByOptName
 (const SharedHandle<RequestGroup>& group, const Option* option,
@@ -405,6 +423,10 @@ void executeHookByOptName
 void executeHookByOptName
 (const RequestGroup* group, const Option* option, const std::string& opt);
 
+std::string createSafePath(const std::string& dir, const std::string& filename);
+
+std::string encodeNonUtf8(const std::string& s);
+
 } // namespace util
 
 } // namespace aria2
